///////////////////////////////////////////////////////////////////////////////
//  untSOAPAdderStub:                                                        //
//  SOAP stub for a TAdder object. Provide object-specific processing for    //
//  SOAP method calls.                                                       //
///////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////
//  Written for the January/February 2001 issue of                           //
//  "uk-bug developer's magazine"                                            //
//  by Rob Bracken                                                           //
//  Bracken Software Limited                                                 //
//  01275 843215                                                             //
///////////////////////////////////////////////////////////////////////////////

unit untSOAPAdderStub;

interface

uses
  untSOAPStub,
  untSOAPAdder,
  XDOM;

type
  TAdderStub = class(TCustomSOAPStub)
  private

    FAdder: TAdder;

  protected

    function ProcessRequest(XMLNode: TDomNode; MethodName: string): string;
                                                                    override;

  public

    constructor Create(ServerObject: TObject); override;

  published

  end;

implementation

uses
  SysUtils;

{ TAdderStub }

constructor TAdderStub.Create(ServerObject: TObject);
begin
  inherited;
  URI := 'SOAPAdder';
  FAdder := FServerObject as TAdder;        // Synonym for ease of use
end;

function TAdderStub.ProcessRequest(XMLNode: TDomNode; MethodName: string):
                                                                         string;
{ Class-specific processing of a SOAP request }
  function CallAddMethod(XMLNode: TDomNode): string;
  { Perform the add method and return the result as XML }
  var
    Int1, Int2: integer;
    Sum: Int64;
    tmpNode: TDomNode;
  const
    SyntaxStuff = [WideChar(#9), WideChar(#10), WideChar(#13)];
  begin
    Result := '<m:Add xmlns:m="SOAPAdder">';
    tmpNode := XMLNode.FirstChild;
    while tmpNode.NodeName <> 'Int1' do
      tmpNode := tmpNode.NextSibling;
    tmpNode := tmpNode.FirstChild;
    while tmpNode.NodeValue[1] in SyntaxStuff do
      tmpNode := tmpNode.NextSibling;
    Int1 := StrToInt(tmpNode.NodeValue);
    tmpNode := tmpNode.ParentNode;
    while tmpNode.NodeName <> 'Int2' do
      tmpNode := tmpNode.NextSibling;
    tmpNode := tmpNode.FirstChild;
    while tmpNode.NodeValue[1] in SyntaxStuff do
      tmpNode := tmpNode.NextSibling;
    Int2 := StrToInt(tmpNode.NodeValue);
    Result := Result + '<Sum>' + IntToStr(FAdder.Add(Int1, Int2)) + '</Sum>';
    Result := Result + '</m:Add>';
  end;

begin

  if Assigned(FAdder) then
  begin
    if UpperCase(MethodName) = 'ADD' then
    begin
      Result := CallAddMethod(XMLNode);
    end;
  end;
  
end;

end.
